@@ -9,8 +9,8 @@ class Parameters : public MathOp {
  public:
   Parameters(int nSup);
 
-  Parameters(const vec & x, const int transf);
-  void setPars(const vec & x, const int transf);
+  Parameters(const vec & x, const int transf, const int check=1);
+  void setPars(const vec & x, const int transf, const int check=1);
   double getPar(const int ind);
 
   static int numberOfSuperPositions(const vec & par);
@@ -18,24 +18,16 @@ class Parameters : public MathOp {
 
   int checkPars(const int transf);
 
+  mat gradient(const int transf);
+
   //  Parameters extractPars(const vec & par);
   vec extractParsInv(const int transf); //const Parameters & parObj);
 
   Parameters(const double mu_, const double psi_,
-	     const vec & omega_, const vec & lambda_, const int transf_);
+	     const vec & omega_, const vec & lambda_, const int transf_, const int check=1);
 
-  void print() const {
-    Rprintf("mu: %8.5f\n", mu);
-    Rprintf("psi: %8.5f ", psi);
-    Rprintf("lambda: ");
-    int n = lambda.n_elem;
-    for (int i=0;i<n;i++)
-      Rprintf("%8.5f ", lambda(i));
-    Rprintf("omega: ");
-    for (int i=0;i<n;i++)
-      Rprintf("%8.5f ", omega(i));
-    Rprintf("\n");
-  };
+  void print() const;
+  void print(const char * str) const;
 
   double psi;
   double mu;
